@@ -201,38 +201,38 @@ def get_file_list_by_suffix(
     for flow_path in target.glob(f"**/*.{suffix}"):
         # 递归尝试过滤
         if len(flow_path.parts) - len(target.parts) > depth:
-            logger.info(f"超过递归深度【{depth}】，忽略：{flow_path}")
+            logger.debug(f"超过递归深度【{depth}】，忽略：{flow_path}")
             continue
 
         # 仅运行指定流程
         _flow_name = get_flow_name(flow_path)
         if flow_name and _flow_name != flow_name:
-            logger.info(f"不满足指定流程名称【{flow_name}】，忽略：{flow_path}")
+            logger.debug(f"不满足指定流程名称【{flow_name}】，忽略：{flow_path}")
             continue
 
         # 仅运行指定版本的流程
         if flow_version and get_flow_version(flow_path) != flow_version:
-            logger.info(f"版本不满足指定要求【{flow_version}】，忽略：{flow_path}")
+            logger.debug(f"版本不满足指定要求【{flow_version}】，忽略：{flow_path}")
             continue
 
         # 按流程忽略列表过滤——判断是否为忽略流程
         if ignore_path and is_ignore(ignore_path, flow_path):
-            logger.info(f"匹配忽略配置文件，忽略：{flow_path}")
+            logger.debug(f"匹配忽略配置文件，忽略：{flow_path}")
             continue
 
         # 仅运行指定作者的流程
         if only_author and get_flow_author(flow_path) != only_author:
-            logger.info(f"不满足仅运行指定作者{only_author}的流程，忽略：{flow_path}")
+            logger.debug(f"不满足仅运行指定作者{only_author}的流程，忽略：{flow_path}")
             continue
 
         # 忽略指定作者的流程
         if ignore_author and get_flow_author(flow_path) == ignore_author:
-            logger.info(f"满足忽略指定作者{only_author}的流程，忽略：{flow_path}")
+            logger.debug(f"满足忽略指定作者{only_author}的流程，忽略：{flow_path}")
             continue
 
         # 忽略包含子流程的流程
         if "子流程" in str(flow_path):
-            logger.info(f"不支持包含子流程的流程，忽略：{flow_path}")
+            logger.debug(f"不支持包含子流程的流程，忽略：{flow_path}")
             continue
 
         # 流程满足以上所有条件，加入待运行列表
