@@ -198,6 +198,7 @@ def pull_repo(
     no_exist_create_modle: str = None,
     consistency_check: bool = True,
     read_only: bool = False,
+    default_branch: str = "master",
 ):
     """拉取代码"""
     start_time = time.perf_counter()
@@ -290,7 +291,7 @@ def pull_repo(
         ):
             logger.info(f"当前已经是预定目标，无需切换：{branch_type}:{branch}:{repo_path}")
         else:
-            utils.execute_cmd(["git", "fetch", remote, "master"], level="debug")
+            utils.execute_cmd(["git", "fetch", remote, default_branch], level="debug")
             utils.execute_cmd(["git", "checkout", branch], level="debug")
     else:
         raise ValueError(f"库{repo_name}目标类型错误，必须为branch,tag,commit中的一种")
