@@ -6,7 +6,7 @@ from requests.cookies import RequestsCookieJar
 from requests.structures import CaseInsensitiveDict
 
 from . import logger
-from .utils import get_caller_info
+from .utils import get_caller_info, MyJSONEncoder
 
 
 def parser_cookies_by_headers(headers: CaseInsensitiveDict):
@@ -81,38 +81,48 @@ def format_output(obj, level="debug", depth=2, caller_info: dict = None):
     _info = caller_info or get_caller_info(depth)
     _logger = getattr(logger, level)
     _logger(f"格式化输出调用源：{_info['output']}")
-    if isinstance(obj, (dict, list, tuple)):
-        _logger(json.dumps(obj, ensure_ascii=False, indent=4))
-    elif isinstance(obj, requests.Response):
-        _logger(f"请求地址：{obj.request.method}, {obj.request.url}")
-        _logger(
-            f"请求头部：{json.dumps(dict(obj.request.headers), ensure_ascii=False, indent=4)}"
-        )
-        if obj.request.body:
-            if obj.request.headers.get(
-                "Content-Type"
-            ) and "application/json" in obj.request.headers.get("Content-Type"):
-                if isinstance(obj.request.body, bytes):
-                    body = json.loads(obj.request.body.decode("utf-8"))
+    try:
+        if isinstance(obj, (dict, list, tuple)):
+            _logger(json.dumps(obj, ensure_ascii=False, indent=4, cls=MyJSONEncoder))
+        elif isinstance(obj, requests.Response):
+            _logger(f"请求地址：{obj.request.method}, {obj.request.url}")
+            _logger(
+                f"请求头部：{json.dumps(dict(obj.request.headers), ensure_ascii=False, indent=4, cls=MyJSONEncoder)}"
+            )
+            if obj.request.body:
+                if obj.request.headers.get(
+                    "Content-Type"
+                ) and "application/json" in obj.request.headers.get("Content-Type"):
+                    if isinstance(obj.request.body, bytes):
+                        body = json.loads(obj.request.body.decode("utf-8"))
+                    else:
+                        body = json.loads(obj.request.body)
+                    _logger(f"请求内容：{json.dumps(body, ensure_ascii=False, indent=4, cls=MyJSONEncoder)}")
+                elif "multipart/form-data" in obj.request.headers.get("Content-Type"):
+                    if isinstance(obj.request.body, bytes):
+                        _logger(f"请求内容：可能包含文件内容，忽略不显示")
+                    else:
+                        _logger(f"请求内容：{str(obj.request.body)}")
                 else:
-                    body = json.loads(obj.request.body)
-                _logger(f"请求内容：{json.dumps(body, ensure_ascii=False, indent=4)}")
-            else:
-                if isinstance(obj.request.body, bytes):
-                    _logger(f"请求内容：{obj.request.body.decode('utf-8')}")
+                    if isinstance(obj.request.body, bytes):
+                        _logger(f"请求内容：{obj.request.body.decode('utf-8')}")
+                    else:
+                        _logger(f"请求内容：{obj.request.body}")
+            _logger(f"响应首行：{obj.status_code}, {obj.reason}, {obj.url}, 耗时：{obj.elapsed}")
+            _logger(f"响应头部：{json.dumps(dict(obj.headers), ensure_ascii=False, indent=4, cls=MyJSONEncoder)}")
+            if obj.text.strip():
+                if obj.headers.get(
+                    "Content-Type"
+                ) and "application/json" in obj.headers.get("Content-Type"):
+                    _logger(f"响应内容：{json.dumps(obj.json(), ensure_ascii=False, indent=4, cls=MyJSONEncoder)}")
                 else:
-                    _logger(f"请求内容：{obj.request.body}")
-        _logger(f"响应首行：{obj.status_code}, {obj.reason}, {obj.url}, 耗时：{obj.elapsed}")
-        _logger(f"响应头部：{json.dumps(dict(obj.headers), ensure_ascii=False, indent=4)}")
-        if obj.text.strip():
-            if obj.headers.get(
-                "Content-Type"
-            ) and "application/json" in obj.headers.get("Content-Type"):
-                _logger(f"响应内容：{json.dumps(obj.json(), ensure_ascii=False, indent=4)}")
-            else:
-                _logger(f"响应内容：{obj.text}")
-    else:
-        _logger(obj)
+                    _logger(f"响应内容：{obj.text}")
+        else:
+            _logger(obj)
+    except Exception as _e:
+        logger.exception(_e)
+        logger.warning("格式法输出对象出错，忽略")
+        _logger(f"type={type(obj)}, value={str(obj)}")
 
 
 def clean_null_key_for_dict(my_dict: dict):
